package SPVM::Mojolicious;

our $VERSION = "0.003";

1;

=head1 Name

SPVM::Mojolicious - Web Frame Work

=head1 Description

Mojolicious in L<SPVM> is a web frame work.

B<WARNINGS:>

This framework is still in early development: there is no documentation yet and method names, functionality and implementations change frequently and without warning.

=head1 Classes

=over 2

=item * L<Mojo::UserAgent|SPVM::Mojo::UserAgent>

=back

=head1 Porting

Mojolicious in L<SPVM> is a Perl's L<Mojolicious> porting to SPVM.

=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright (c) 2025 Yuki Kimoto

MIT License

